#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const env_1 = require("@next/env");
const path_1 = __importDefault(require("path"));
const package_json_1 = require("../package.json");
const fullDescription = `${package_json_1.description}.

Examples:
  $ next-env-cmd node start.js          # load .env files in CWD
  $ next-env-cmd -d ~/ node start.js    # load .env files in ~/
  $ nexenv -p ../ node start.js         # alias shorthand command`;
// prepare cli and args
commander_1.program
    .name(package_json_1.name)
    .version(package_json_1.version, '-v, --version')
    .description(fullDescription)
    .usage('[options] <command> [...args]')
    .option('-d, --dir [path]', 'Custom env directory path', './')
    .option('-p, --parent [path]', 'Parent env directory path to be merged as defaults')
    .option('--production', 'Forcely load production env files')
    .allowUnknownOption(true)
    .parse(process.argv);
// prepare variables
const opts = commander_1.program.opts();
const args = commander_1.program.args;
const pwd = process.env.PWD || '';
let dev = (process.env.NODE_ENV || 'development') === 'development';
let mainEnv = {};
let parentEnv = {};
// override to load production env files
if (opts.production)
    dev = false;
// load parent env directory first
if (opts.parent) {
    parentEnv = (0, env_1.loadEnvConfig)(path_1.default.resolve(pwd, opts.parent), dev).combinedEnv;
}
// load main env directory
mainEnv = (0, env_1.loadEnvConfig)(path_1.default.resolve(pwd, opts.dir), dev, undefined, true).combinedEnv;
// combine variables
Object.assign(process.env, Object.assign(Object.assign({ NODE_ENV: process.env.NODE_ENV || (dev ? 'development' : 'production') }, parentEnv), mainEnv));
// spawn command and gracefully exit process
const ps = (0, cross_spawn_1.default)(args[0], args.slice(1), { stdio: 'inherit' });
ps.on('exit', (status) => process.exit(status || undefined));
process.on('SIGTERM', () => ps.kill());
